require_dependency 'hr_engine6/application_controller'
require 'aws-sdk'

module HrEngine6
  class JobApplicantsController < ApplicationController
    before_action :set_job_applicant, only: [:show, :edit, :update, :destroy]

    # GET /job_applicants
    # GET /job_applicants.json
    def index
      @job_applicants = JobApplicant.all
    end

    # GET /job_applicants/1
    # GET /job_applicants/1.json
    def show
    end

    # GET /job_applicants/new
    def new
      @job_applicant = JobApplicant.new
    end

    # GET /job_applicants/1/edit
    def edit
    end

    # POST /job_applicants
    # POST /job_applicants.json
    def create
      @job_applicant = JobApplicant.new(job_applicant_params)

      respond_to do |format|
        if @job_applicant.save
          s3 = Aws::S3::Resource.new

          #dosyanın kabul edilen fotoğraf formatlarından biriyle bitmesi önemli
          if(params['job_applicant'][:image].present?) #image seçilmişse yükle
            if params['job_applicant'][:image].original_filename.include?('png')
              upload_file('png', s3)
            elsif params['job_applicant'][:image].original_filename.include?('jpeg')
              upload_file('jpeg', s3)
            elsif params['job_applicant'][:image].original_filename.include?('jpg')
              upload_file('jpeg', s3)
            end
          end

          #dosyanın kabul edilen döküman formatlarından biriyle bitmesi önemli
          if(params['job_applicant'][:cv].present?) #cv seçilmişse yükle
            if params['job_applicant'][:cv].original_filename.include?('doc')
              upload_file('doc', s3)
            elsif params['job_applicant'][:cv].original_filename.include?('docx')
              upload_file('docx', s3)
            elsif params['job_applicant'][:cv].original_filename.include?('pdf')
              upload_file('pdf', s3)
            end
          end


          format.html { redirect_to @job_applicant, notice: 'Aday profili başarıyla oluşturuldu.' }
          format.json { render :show, status: :created, location: @job_applicant }
        else
          format.html { render :new }
          format.json { render json: @job_applicant.errors, status: :unprocessable_entity }
        end
      end
    end

    # PATCH/PUT /job_applicants/1
    # PATCH/PUT /job_applicants/1.json
    def update
      respond_to do |format|
        if @job_applicant.update(job_applicant_params)
          format.html { redirect_to @job_applicant, notice: 'Aday profili başarıyla güncellendi.' }
          format.json { render :show, status: :ok, location: @job_applicant }
        else
          format.html { render :edit }
          format.json { render json: @job_applicant.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /job_applicants/1
    # DELETE /job_applicants/1.json
    def destroy
      @job_applicant.destroy
      respond_to do |format|
        format.html { redirect_to job_applicants_url, notice: 'Aday profili başarıyla silindi.' }
        format.json { head :no_content }
      end
    end

    private

    # Use callbacks to share common setup or constraints between actions.
    def set_job_applicant
      @job_applicant = JobApplicant.find(params[:id])
    end

    # Only allow a list of trusted parameters through.
    def job_applicant_params
      params.require(:job_applicant).permit(:name, :surname, :birth_date, :birth_place, :address, :e_mail,
                                            :mobile_phone, :house_phone, :nationality, :graduated_school, :position,
                                            :foreign_language, :hr_engine6_job_listing_id)
    end

    #dosyayı aws'ye yükleyen metod
    def upload_file(ext, s3)

      #dosyayı oluştur ve içine veriyi yaz
      open("/tmp/file#{@job_applicant.id}.#{ext}", 'w+') do |file|
        if ext == 'png' || ext == 'jpeg' || ext == 'jpg'
          file << File.open(params['job_applicant'][:image].tempfile).read
        elsif ext == 'doc' || ext == 'docx' || ext == 'pdf'
          file << File.open(params['job_applicant'][:cv].tempfile).read
        end

        name = File.basename(file) #extension'ıyla birlikte döndürüyor
        object = s3.bucket('futurino').object("hr/#{name}")
        #Parametre olarak File objesini değil de path'ini vermemiz önemli, aksi takdirde çok yavaş çalışıyor
        object.upload_file(file.path)

        #bitince dosyayı local makineden silebiliriz, ihtiyacımız kalmadı
        FileUtils.rm_rf(file.path)
      end
    end

  end
end
